@@ -60,33 +60,35 @@ class ConfigHeaderMappings():
                 logger.exception('Failed to read header mappings from configuration, skipping')
         return self._header_mappings.get(taxonomy_id, {})
 
+    async def fetch(self, request):
+        return await _configs(request)
+
     async def refresh(self, request):
-        async with request.app['db'].acquire() as conn:
-            configurations = await _configs(request)
-            for config in configurations:
-                config = config.get('config', {})
-                taxonomy_id = config.get('taxonomy', {}).get('id')
-                if not taxonomy_id:
-                    continue
-                mapping = config.get('model', {}).get('mapping')
-                if not mapping:
-                    continue
-                for m in mapping:
-                    name = m.get('name')
-                    columnType = m.get('columnType')
-                    normalize = m.get('normalize')
-                    normalizeTarget = m.get('normalizeTarget')
-                    if normalize and normalizeTarget:
-                        h = dict(
-                            normalize=dict(
-                                header=normalizeTarget,
-                                using=normalize
-                            )
+        configurations = await self.fetch(request)
+        for config in configurations:
+            config = config.get('config', {})
+            taxonomy_id = config.get('taxonomy', {}).get('id')
+            if not taxonomy_id:
+                continue
+            mapping = config.get('model', {}).get('mapping')
+            if not mapping:
+                continue
+            for m in mapping:
+                name = m.get('name')
+                columnType = m.get('columnType')
+                normalize = m.get('normalize')
+                normalizeTarget = m.get('normalizeTarget')
+                if normalize and normalizeTarget:
+                    h = dict(
+                        normalize=dict(
+                            header=normalizeTarget,
+                            using=normalize
                         )
-                    elif columnType:
-                        h = dict(
-                            type=columnType
-                        )
-                    else:
-                        continue
-                    self._header_mappings.setdefault(taxonomy_id, {})[name] = h
+                    )
+                elif columnType:
+                    h = dict(
+                        type=columnType
+                    )
+                else:
+                    continue
+                self._header_mappings.setdefault(taxonomy_id, {})[name] = h
